@@ -4,7 +4,7 @@ import lala.config
 import lala.util
 
 
-__all__ = ["disable", "enable", "is_admin"]
+__all__ = ["disable", "enable", "is_admin", "PluginFunc", "load_plugin"]
 
 
 _callbacks = {}
@@ -14,16 +14,23 @@ _cbprefix = "!"
 
 
 class PluginFunc(object):
-    __slots__ = ['enabled', 'func', 'admin_only']
-
-    def __init__(self, func, enabled=True, admin_only=False):
+    def __init__(self, func, enabled=True, admin_only=False, aliases=None):
         self.enabled = enabled
         self.func = func
         self.admin_only = admin_only
+        self.aliases = aliases or []
 
 
-def _make_pluginfunc(func, admin_only=False):
-    return PluginFunc(enabled=True, func=func, admin_only=admin_only)
+def _make_pluginfunc(func, admin_only=False, aliases=None):
+    if aliases is not None:
+        extradoc = "Aliases: %s" % (", ".join(aliases))
+        doc = func.__doc__
+        if doc is None:
+            func.__doc__ = extradoc
+        else:
+            func.__doc__ += "\n"
+            func.__doc__ += extradoc
+    return PluginFunc(func,admin_only=admin_only, aliases=aliases)
 
 
 def is_admin(user):
@@ -34,7 +41,8 @@ def is_admin(user):
 
     If no nickserv password is set, this simply checks if ``user`` is in
     the "admins" option of the "base" section."""
-    if lala.util._BOT.factory.nspassword is not None:
+    if lala.util._BOT.factory.nspassword is not None and\
+       lala.config._CFG.getboolean("base", "nickserv_admin_tracking"):
         return user in lala.util._BOT.identified_admins
     else:
         return user in lala.config._get("base",
@@ -50,10 +58,14 @@ def load_plugin(name):
     imp.load_module(name, f, p, d)
 
 
-def register_callback(trigger, func, admin_only=False):
+def register_callback(trigger, func, admin_only=False, aliases=None):
     """ Adds ``func`` to the callbacks for ``trigger``."""
     logging.debug("Registering callback for %s" % trigger)
-    _callbacks[trigger] = _make_pluginfunc(func, admin_only)
+    f = _make_pluginfunc(func, admin_only, aliases)
+    if aliases is not None:
+        for alias in aliases:
+            _callbacks[alias] = f
+    _callbacks[trigger] = f
 
 
 def register_join_callback(func):
@@ -114,7 +126,7 @@ def on_join(user, channel):
 def disable(trigger):
     """Disables `trigger`.
 
-    :trigger: The trigger to disable. Can be a key for a callback or a
+    :param str trigger: The trigger to disable. Can be a key for a callback or a
     regular expression
     """
     if trigger in _callbacks:
@@ -129,7 +141,7 @@ def disable(trigger):
 def enable(trigger):
     """Enables `trigger`.
 
-    :trigger: The trigger to enable. Can be a key for a callback or a
+    :param str trigger: The trigger to enable. Can be a key for a callback or a
     regular expression
 
     """
