@@ -27,6 +27,8 @@ class command(object):
             channel, text):
                 pass
 
+        ``aliases`` can be a list of names under which the function will be
+        available in addition to its primary name.
 
         An additional argument, ``admin_only`` can be used to make a function
         available to admins only::
@@ -35,15 +37,16 @@ class command(object):
             def give_me_the_one_ring(user, channel, text):
                 pass
     """
-    def __init__(self, command=None, admin_only=False):
+    def __init__(self, command=None, admin_only=False, aliases=None):
         self.admin_only = admin_only
+        self.aliases = aliases
         if isinstance(command, FunctionType):
-            if _check_args(command):
-                lala.pluginmanager.register_callback(command.__name__, command,
-                                                     self.admin_only)
-            else:
-                raise TypeError(
-                    "A callback function should take exactly 3 arguments")
+            # Used like
+            # @command
+            # def foo(...):
+            #     pass
+            self.cmd = None
+            self._handle_func(command)
         elif command is None:
             # This happens when only admin_only is set when decorating a
             # function like
@@ -53,15 +56,28 @@ class command(object):
             self.cmd = None
         elif not (isinstance(command, str) or isinstance(command, unicode)):
             raise TypeError(
-                    "The command should be either a str or unicode but it's %s"
-                    % type(command))
+                "The command should be either a str or unicode but it's %s"
+                % type(command))
         else:
             self.cmd = command
-            self.admin_only=admin_only
 
     def __call__(self, func):
-        self.cmd = self.cmd or func.__name__
-        lala.pluginmanager.register_callback(self.cmd, func, self.admin_only)
+        self._handle_func(func)
+
+    def _handle_func(self, f):
+        if _check_args(f):
+            self.cmd = self.cmd or f.__name__
+            self.func = f
+            self._register()
+        else:
+            raise TypeError(
+                "A callback function should take exactly 3 arguments")
+
+    def _register(self):
+        lala.pluginmanager.register_callback(self.cmd,
+                                             self.func,
+                                             self.admin_only,
+                                             self.aliases)
 
 
 def on_join(f):
@@ -102,9 +118,10 @@ class regex(object):
 def msg(target, message, log=True):
     """Send a message to a target.
 
-    :param target: Target to send the message to. Can be a channel or user
+    :param str target: Target to send the message to. Can be a channel or user
     :param message: One or more messages to send
-    :param log: Whether or not to log the message
+    :type message: str or [str]
+    :param bool log: Whether or not to log the message
     """
     try:
         if not isinstance(message, basestring):
