@@ -5,7 +5,7 @@ except ImportError:
     import unittest
 import mock
 
-from lala import util, pluginmanager, config
+from lala import util, pluginmanager
 from re import compile
 
 
@@ -45,6 +45,17 @@ class TestPluginmanager(unittest.TestCase):
         self.assertEqual(len(pluginmanager._callbacks), 1)
         self.assertTrue("f" in pluginmanager._callbacks)
 
+    def test_command_aliases(self):
+        self.assertEqual(len(pluginmanager._callbacks), 0)
+
+        util.command(f, aliases=["foo", "bar"])
+
+        self.assertTrue("Aliases: foo, bar" in pluginmanager._callbacks["f"].func.__doc__)
+        self.assertTrue("foo" in pluginmanager._callbacks.keys())
+        self.assertTrue("bar" in pluginmanager._callbacks.keys())
+        self.assertEqual(pluginmanager._callbacks["foo"], pluginmanager._callbacks["bar"])
+        self.assertEqual(pluginmanager._callbacks["f"], pluginmanager._callbacks["bar"])
+
     def test_named_command(self):
         self.assertEqual(len(pluginmanager._callbacks), 0)
 
@@ -55,20 +66,22 @@ class TestPluginmanager(unittest.TestCase):
         self.assertTrue("command" in pluginmanager._callbacks)
 
     def test_disabled_command(self):
-        c = util.command("command")
+        c = util.command("command", aliases=["foo"])
         c(f3)
 
         pluginmanager.disable("command")
         self.assertFalse(pluginmanager._callbacks["command"].enabled)
+        self.assertFalse(pluginmanager._callbacks["foo"].enabled)
         pluginmanager._handle_message("user", "channel", "!command")
 
     def test_reenabled_command(self):
-        c = util.command("command")
+        c = util.command("command", aliases=["foo"])
         c(f3)
 
         pluginmanager.disable("command")
         pluginmanager.enable("command")
         self.assertTrue(pluginmanager._callbacks["command"].enabled)
+        self.assertTrue(pluginmanager._callbacks["foo"].enabled)
         self.assertRaises(ValueError, pluginmanager._handle_message, "user",
         "channel", "!command")
 
@@ -124,16 +137,25 @@ class TestPluginmanager(unittest.TestCase):
 
     @mock.patch("lala.config._get")
     def test_is_admin_no_nickserv(self, mock):
-        util._BOT.factory.nspassword= None
+        util._BOT.factory.nspassword = None
         mock.return_value = "superman,gandalf"
         self.assertTrue(pluginmanager.is_admin("superman"))
         self.assertFalse(pluginmanager.is_admin("i'm-no-superman"))
 
-    @mock.patch("lala.config._get")
-    def test_is_admin_with_nickserv(self, mock):
+    @mock.patch.multiple("lala.config", _get=mock.DEFAULT, _CFG=mock.DEFAULT)
+    def test_is_admin_with_nickserv(self, _get, _CFG):
         util._BOT.factory.nspassword = "foobar"
         util._BOT.identified_admins = ["superman"]
-        mock.return_value = "superman,gandalf"
+        _get.return_value = "superman,gandalf"
+        _CFG.getboolean.return_value = True
+        self.assertTrue(pluginmanager.is_admin("superman"))
+        self.assertFalse(pluginmanager.is_admin("i'm-no-superman"))
+
+    @mock.patch.multiple("lala.config", _get=mock.DEFAULT, _CFG=mock.DEFAULT)
+    def test_is_admin_with_explicitly_disabled_nickserv(self, _get, _CFG):
+        util._BOT.factory.nspassword = "testpassword"
+        _get.return_value = "superman,gandalf"
+        _CFG.getboolean.return_value = False
         self.assertTrue(pluginmanager.is_admin("superman"))
         self.assertFalse(pluginmanager.is_admin("i'm-no-superman"))
 
@@ -146,7 +168,6 @@ class TestPluginmanager(unittest.TestCase):
     def test_admin_only_command_as_non_admin(self, mock):
         util._BOT.factory.nspassword= None
         mock.return_value = "superman"
-        func_mock = mock.Mock()
-        util.command(command="mock", admin_only=True)(func_mock)
+
+        util.command(command="mock", admin_only=True)(f3)
         pluginmanager._handle_message("gandalf", "#channel", "!mock")
-        self.assertFalse(func_mock.called)
