@@ -6,7 +6,7 @@ except ImportError:
 import lala.pluginmanager
 import mock
 
-from lala import util, config
+from lala import util
 from re import compile
 
 
@@ -38,12 +38,17 @@ class TestUtil(unittest.TestCase):
 
     def test_command(self):
         util.command(f)
-        lala.pluginmanager.register_callback.assert_called_once_with("f", f, False)
+        lala.pluginmanager.register_callback.assert_called_once_with("f", f, False, None)
 
     def test_named_command(self):
         c = util.command("command")
         c(f)
-        lala.pluginmanager.register_callback.assert_called_once_with("command", f, False)
+        lala.pluginmanager.register_callback.assert_called_once_with("command", f, False, None)
+
+    def test_command_aliases(self):
+        c = util.command(aliases=["foo", "bar"])
+        c(f)
+        lala.pluginmanager.register_callback.assert_called_once_with("f", f, False, ["foo", "bar"])
 
     def test_command_str(self):
         self.assertRaises(TypeError, util.command, object())
@@ -78,4 +83,3 @@ class TestUtil(unittest.TestCase):
         self.assertFalse(util._BOT.msg.called)
         util.msg("user", ["", ""])
         self.assertFalse(util._BOT.msg.called)
-
